@@ -1,4 +1,4 @@
-#pragma once
+﻿#pragma once
 
 /**************************************************************************************************
 Platform
@@ -80,11 +80,7 @@ Global includes
 #define APE_MIN(a, b) (((a) < (b)) ? (a) : (b))
 #define APE_CAP(value, low, high) (((value) < (low)) ? (low) : ((value) > (high)) ? (high) : (value))
 #define APE_CLEAR(destination) memset(&destination, 0, sizeof(destination))
-
-/**************************************************************************************************
-Smart pointer
-**************************************************************************************************/
-#include "SmartPtr.h"
+#define APE_CLEAR_ARRAY(destination, elements) memset(&destination[0], 0, sizeof(destination[0]) * static_cast<size_t>(elements))
 
 /**************************************************************************************************
 Version
@@ -92,7 +88,7 @@ Version
 #include "Version.h"
 
 // year in the copyright strings
-#define APE_YEAR 2025
+#define APE_YEAR 2026
 
 // build the version string
 #define STRINGIZE2(s) #s
@@ -109,7 +105,7 @@ Version
 #define MJ_PLUGIN_NAME                                  _T("APE Plugin (v") APE_VER_FILE_VERSION_STR _T(")")
 #define APE_RESOURCE_VERSION_COMMA                      APE_VERSION_MAJOR, APE_VERSION_REVISION, 0, 0
 #define APE_RESOURCE_VERSION_STRING                     APE_VER_FILE_VERSION_STR
-#define APE_RESOURCE_COPYRIGHT                          "Copyright (c) 2000-" STRINGIZE(APE_YEAR) " Matthew T. Ashland"
+#define APE_RESOURCE_COPYRIGHT                          "Copyright © 2000-" STRINGIZE(APE_YEAR) " by Matthew T. Ashland"
 #define CONSOLE_NAME                                    L"--- Monkey's Audio Console Front End (v " APE_VER_FILE_VERSION_STR_WIDE L") (c) Matthew T. Ashland ---\n"
 #define PLUGIN_ABOUT                                    _T("Monkey's Audio Player v") APE_VER_FILE_VERSION_STR _T("\nCopyrighted (c) 2000-") STRINGIZE(APE_YEAR) _T(" by Matthew T. Ashland")
 
@@ -153,6 +149,11 @@ namespace APE
     typedef wchar_t                                     str_utfn; // could be UTF-16 or UTF-32 depending on platform
 }
 
+/**************************************************************************************************
+Smart pointer
+**************************************************************************************************/
+#include "SmartPtr.h"
+
 /**************************************************************************************************
 Global macros
 **************************************************************************************************/
@@ -259,8 +260,9 @@ WAVE format descriptor (binary compatible with Windows define, but in the APE na
 namespace APE
 {
     #pragma pack(push, 1)
-    struct WAVEFORMATEX
+    class WAVEFORMATEX
     {
+    public:
         WORD        wFormatTag;         /* format type */
         WORD        nChannels;          /* number of channels (i.e. mono, stereo...) */
         uint32      nSamplesPerSec;     /* sample rate */
@@ -269,6 +271,18 @@ namespace APE
         WORD        wBitsPerSample;     /* number of bits per sample of mono data */
         WORD        cbSize;             /* the count in bytes of the size of */
         /* extra information (after cbSize) */
+
+        WAVEFORMATEX()
+        {
+            // initialize everything to empty on construction (avoids the need to clear variables separately)
+            wFormatTag = 0;
+            nChannels = 0;
+            nSamplesPerSec = 0;
+            nAvgBytesPerSec = 0;
+            nBlockAlign = 0;
+            wBitsPerSample = 0;
+            cbSize = 0;
+        }
     };
     #pragma pack(pop)
 }
